Python bindings documentation of delta-rs
=========================================================
This is the documentation of the Python bindings of delta-rs.


.. toctree::
   :maxdepth: 2

   installation
   usage
   api_reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
